/* Convex Hull
   Graham Scan
   O(n * log n)

	1. Se alege punctul (p[1]) cu y minim si cel mai din stanga  O(n)
	2. Se ordoneaza restul punctelor (p[i]) dupa unghiul pe care il face segmentul [p[1], p[i]] cu axa OX  - O(n * log n)
	3. Se plaseaza p[1] si p[2] in stiva
	4. Pentru i = 3,..., n, cat timp segmentul [stk.top, p[i]] se intoarce la dreapta fata de [stk[top - 1], stk[top]]
	   se scoate stk.top din stiva.
	5. Se plaseaza p[i] in stiva
	6. Punctele care raman in stiva la final reprezinta infasuratoarea convexa
*/
#include <algorithm>
#include <fstream>
#include <iomanip>
using namespace std;

#define x second
#define y first        // sortez crescator dupa y si la acelasi y dupa x
               y       x
typedef pair<double, double> Point;

ifstream fin("infasuratoare.in");
ofstream fout("infasuratoare.out");

const int MAX_N = 120005;

int n;
Point p[MAX_N];

Point stk[MAX_N];
int top;

void Read()
{
    fin >> n;
    for (int i = 1; i <= n; ++i)
        fin >> p[i].x >> p[i].y;
}

inline double CrossProduct(const Point& A, const Point& B, const Point& C)
{
    return (B.x - A.x) * (C.y - A.y) - (B.y - A.y) * (C.x - A.x);
}

void SortPoints()
{
    int pos = 1;
    for (int i = 2; i <= n; ++i)
        if (p[i] < p[pos]) // compara y
            pos = i;
    swap(p[1], p[pos]);
    sort(p + 2, p + n + 1, [](const Point& p1, const Point& p2) {
		return CrossProduct(p[1], p1, p2) > 0;
	});
}

void ConvexHull()
{
    SortPoints();

    stk[1] = p[1];
    stk[2] = p[2];
    top = 2;
    for (int i = 3; i <= n; ++i)
    {
        while (top >= 2 && CrossProduct(stk[top - 1], stk[top], p[i]) < 0)
            --top;
        stk[++top] = p[i];
    }
}

void Write()
{
    fout << top << '\n';
    for (int i = 1; i <= top; ++i )      // in stiva punctele sunt acum in ordine trigonometrica
        fout << fixed << setprecision(9) << stk[i].x << ' ' << stk[i].y << '\n';
}

int main()
{
    Read();
    ConvexHull();
    Write();
}
